@@ -1,5 +1,8 @@
 package Lingua::Base::Number::Format::MixWithWords;
 
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -8,8 +11,6 @@ use Math::Round qw(nearest);
 use Number::Format;
 use POSIX qw(floor ceil log10);
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 sub new {
@@ -78,7 +79,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -86,26 +87,35 @@ Lingua::Base::Number::Format::MixWithWords - Base class for Lingua::XX::Number::
 
 =head1 VERSION
 
-version 0.07
+This document describes version 0.08 of Lingua::Base::Number::Format::MixWithWords (from Perl distribution Lingua-EN-Number-Format-MixWithWords), released on 2016-06-14.
 
 =for Pod::Coverage ^(new)$
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Lingua-EN-Number-Format-MixWithWords>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Lingua-EN-Number-Format-MixWithWords>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-EN-Number-Format-MixWithWords>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =cut
