@@ -1,5 +1,8 @@
 package Lingua::EN::Number::Format::MixWithWords;
 
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -7,49 +10,56 @@ use warnings;
 use Lingua::Base::Number::Format::MixWithWords;
 use parent qw(Lingua::Base::Number::Format::MixWithWords);
 
-use Exporter::Lite;
-
+use Exporter qw(import);
 our @EXPORT_OK = qw(format_number_mix);
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 $SPEC{format_number_mix} = {
-    summary => '',
+    v => 1.1,
+    summary => 'Format number to a mixture of numbers and words (e.g. 12.3 million)',
     args    => {
-        num => ['float*' => {
+        num => {
             summary => 'The input number to format',
-        }],
-        scale => ['str*' => {
+            schema => ['float*' => {}],
+        },
+        scale => {
             summary => 'Pick long or short scale names',
             description => <<_,
 See http://en.wikipedia.org/wiki/Long_scale#Long_scale_countries_and_languages
 for details.
 _
-            in => ['short', 'long'],
-        }],
-        num_decimal => ['int' => {
+            schema => ['str*' => {
+                in => ['short', 'long'],
+            }],
+        },
+        num_decimal => {
             summary => 'Number of decimal points to round',
             description => <<'_',
 Can be negative, e.g. -1 to round to nearest 10, -2 to nearest 100, and so on.
 _
-        }],
-        min_format => ['float*' => {
+            schema => ['int' => {
+            }],
+        },
+        min_format => {
             summary => 'Number must be larger than this to be formatted as '.
                 'mixture of number and word',
+            schema => ['float*' => {
+            }],
             default => 1000000,
-        }],
-        min_fraction => ['float*' => {
+        },
+        min_fraction => {
             summary => 'Whether smaller number can be formatted with 0,x',
             description => <<_,
 If min_fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
 omillion but will be if min_fraction is 0.8.
 _
+            schema => ['float*' => {
+                min => 0,
+                max => 1,
+            }],
             default => 1,
-            min => 0,
-            max => 1,
-        }],
+        },
     },
     result_naked => 1,
 };
@@ -140,7 +150,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -148,7 +158,7 @@ Lingua::EN::Number::Format::MixWithWords - Format number to a mixture of numbers
 
 =head1 VERSION
 
-version 0.07
+This document describes version 0.08 of Lingua::EN::Number::Format::MixWithWords (from Perl distribution Lingua-EN-Number-Format-MixWithWords), released on 2016-06-14.
 
 =head1 SYNOPSIS
 
@@ -165,13 +175,13 @@ formatted like a normal number.
 
 =head1 FUNCTIONS
 
-None of the functions are exported by default, but they are exportable.
-
-
-None are exported by default, but they are exportable.
 
 =head2 format_number_mix(%args) -> any
 
+Format number to a mixture of numbers and words (e.g. 12.3 million).
+
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -184,8 +194,8 @@ Number must be larger than this to be formatted as mixture of number and word.
 
 Whether smaller number can be formatted with 0,x.
 
-If minI<fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
-omillion but will be if min>fraction is 0.8.
+If min_fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
+omillion but will be if min_fraction is 0.8.
 
 =item * B<num> => I<float>
 
@@ -201,12 +211,28 @@ Can be negative, e.g. -1 to round to nearest 10, -2 to nearest 100, and so on.
 
 Pick long or short scale names.
 
-See http://en.wikipedia.org/wiki/LongI<scale#Long>scaleI<countries>and_languages
+See http://en.wikipedia.org/wiki/Long_scale#Long_scale_countries_and_languages
 for details.
 
 =back
 
-Return value:
+Return value:  (any)
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Lingua-EN-Number-Format-MixWithWords>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Lingua-EN-Number-Format-MixWithWords>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-EN-Number-Format-MixWithWords>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
@@ -216,11 +242,11 @@ L<Number::Format>
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
